
from importlib import import_module

from django.apps import apps
from django.db import models
from django.contrib import admin

from ordered_model.admin import OrderedModelAdmin

from faq.models import Question


def _get_question_admin_base_class():

    if apps.is_installed('modeltranslation'):
        return import_module('modeltranslation.admin').TranslationAdmin

    return admin.ModelAdmin


@admin.register(Question)
class QuestionAdmin(_get_question_admin_base_class(), OrderedModelAdmin):

    list_display = ['question', 'move_up_down_links']

    def __init__(self, *args, **kwargs):

        if apps.is_installed('ckeditor_uploader'):
            from ckeditor_uploader.widgets import CKEditorUploadingWidget
            self.formfield_overrides = {
                models.TextField: {'widget': CKEditorUploadingWidget}
            }

        elif apps.is_installed('ckeditor'):
            from ckeditor.widgets import CKEditorWidget
            self.formfield_overrides = {
                models.TextField: {'widget': CKEditorWidget}
            }

        super().__init__(*args, **kwargs)




from django.db import models
from django.utils.translation import ugettext_lazy as _

from ordered_model.models import OrderedModel


class Question(OrderedModel):

    question = models.CharField(_('Question'), max_length=255, unique=True)

    answer = models.TextField(_('Answer'), max_length=10000)

    def __str__(self):
        return self.question

    class Meta(OrderedModel.Meta):
        verbose_name = _("Frequent asked question")
        verbose_name_plural = _("Frequently asked questions")



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


def setup_settings(settings, is_prod, **kwargs):

    settings['INSTALLED_APPS'] += [
        app for app in [
            'faq',
            'ordered_model'
        ] if app not in settings['INSTALLED_APPS']
    ]


class FAQConfig(AppConfig):
    name = 'faq'
    verbose_name = _("FAQ")


default_app_config = 'faq.FAQConfig'



# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-02-25 14:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faq', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ('order',), 'verbose_name': 'Frequent asked question', 'verbose_name_plural': 'Frequently asked questions'},
        ),
        migrations.AddField(
            model_name='question',
            name='order',
            field=models.PositiveIntegerField(db_index=True, default=1, editable=False),
            preserve_default=False,
        )
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-06-10 13:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Question',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('question', models.CharField(max_length=255, unique=True, verbose_name='Question')),
                ('answer', models.TextField(max_length=10000, verbose_name='Answer')),
            ],
            options={
                'verbose_name': 'Frequent asked question',
                'verbose_name_plural': 'Frequently asked questions',
            },
        ),
    ]
